Learn R Programming

popEpi (version 0.3.0)

lines.survmean: Graphically Inspect Curves Used in Mean Survival Computation

Description

Plots the observed (with extrapolation) and expected survival curves for all strata in an object created by survmean

Usage

## S3 method for class 'survmean':
lines(x, ...)

Arguments

x
a survmean object
...
arguments passed (ultimately) to matlines; you may, therefore, supply e.g. lwd through this, though arguments such as lty and col will not work

Details

This function is intended to be a workhorse for plot.survmean. If you want finer control over the plotted curves, extract the curves from the survmean output using

attr(x, "curves")

where x is a survmean object.