lines.survtab: lines method for survtab objects
Description
Plot lines from a survtab objectUsage
## S3 method for class 'survtab':
lines(x, y = NULL, subset = NULL, conf.int = TRUE,
col = NULL, lty = NULL, ...)
Arguments
y
a variable to plot; a quoted name of a variable
in x; e.g. "surv.obs";
if NULL, picks last survival variable column in order in x
subset
a logical condition; x is subset accordingly
before plotting
conf.int
logical; if TRUE, plots confidence regions as well
col
line colour passed to matlines
lty
line type passed to matlines
...
additional arguments passed on to to a matlines call;
e.g. lwd can be defined this way